@@ -5,23 +5,24 @@ pub mod merge_ff;
 pub mod merge_rebase;
 pub mod rename;
 
-use std::collections::HashSet;
-
 use super::{
 	remotes::get_default_remote_in_repo, utils::bytes2string,
+	RepoPath,
 };
 use crate::{
 	error::{Error, Result},
-	sync::{utils, CommitId},
+	sync::{repository::repo, utils::get_head_repo, CommitId},
 };
 use git2::{Branch, BranchType, Repository};
 use scopetime::scope_time;
-use utils::get_head_repo;
+use std::collections::HashSet;
 
 /// returns the branch-name head is currently pointing to
 /// this might be expensive, see `cached::BranchName`
-pub(crate) fn get_branch_name(repo_path: &str) -> Result<String> {
-	let repo = utils::repo(repo_path)?;
+pub(crate) fn get_branch_name(
+	repo_path: &RepoPath,
+) -> Result<String> {
+	let repo = repo(repo_path)?;
 
 	get_branch_name_repo(&repo)
 }
@@ -111,12 +112,12 @@ pub fn validate_branch_name(name: &str) -> Result<bool> {
 /// returns a list of `BranchInfo` with a simple summary on each branch
 /// `local` filters for local branches otherwise remote branches will be returned
 pub fn get_branches_info(
-	repo_path: &str,
+	repo_path: &RepoPath,
 	local: bool,
 ) -> Result<Vec<BranchInfo>> {
 	scope_time!("get_branches_info");
 
-	let repo = utils::repo(repo_path)?;
+	let repo = repo(repo_path)?;
 
 	let (filter, remotes_with_tracking) = if local {
 		(BranchType::Local, HashSet::default())
@@ -214,10 +215,10 @@ pub(crate) fn branch_set_upstream(
 
 /// returns remote of the upstream tracking branch for `branch`
 pub fn get_branch_remote(
-	repo_path: &str,
+	repo_path: &RepoPath,
 	branch: &str,
 ) -> Result<Option<String>> {
-	let repo = utils::repo(repo_path)?;
+	let repo = repo(repo_path)?;
 	let branch = repo.find_branch(branch, BranchType::Local)?;
 	let reference = bytes2string(branch.get().name_bytes())?;
 	let remote_name = repo.branch_upstream_remote(&reference).ok();
@@ -229,8 +230,8 @@ pub fn get_branch_remote(
 }
 
 /// returns whether the pull merge strategy is set to rebase
-pub fn config_is_pull_rebase(repo_path: &str) -> Result<bool> {
-	let repo = utils::repo(repo_path)?;
+pub fn config_is_pull_rebase(repo_path: &RepoPath) -> Result<bool> {
+	let repo = repo(repo_path)?;
 	let config = repo.config()?;
 
 	if let Ok(rebase) = config.get_entry("pull.rebase") {
@@ -244,12 +245,12 @@ pub fn config_is_pull_rebase(repo_path: &str) -> Result<bool> {
 
 ///
 pub fn branch_compare_upstream(
-	repo_path: &str,
+	repo_path: &RepoPath,
 	branch: &str,
 ) -> Result<BranchCompare> {
 	scope_time!("branch_compare_upstream");
 
-	let repo = utils::repo(repo_path)?;
+	let repo = repo(repo_path)?;
 
 	let branch = repo.find_branch(branch, BranchType::Local)?;
 
@@ -269,14 +270,14 @@ pub fn branch_compare_upstream(
 
 /// Modify HEAD to point to a branch then checkout head, does not work if there are uncommitted changes
 pub fn checkout_branch(
-	repo_path: &str,
+	repo_path: &RepoPath,
 	branch_ref: &str,
 ) -> Result<()> {
 	scope_time!("checkout_branch");
 
 	// This defaults to a safe checkout, so don't delete anything that
 	// hasn't been committed or stashed, in this case it will Err
-	let repo = utils::repo(repo_path)?;
+	let repo = repo(repo_path)?;
 	let cur_ref = repo.head()?;
 	let statuses = repo.statuses(Some(
 		git2::StatusOptions::new().include_ignored(false),
@@ -302,12 +303,12 @@ pub fn checkout_branch(
 
 ///
 pub fn checkout_remote_branch(
-	repo_path: &str,
+	repo_path: &RepoPath,
 	branch: &BranchInfo,
 ) -> Result<()> {
 	scope_time!("checkout_remote_branch");
 
-	let repo = utils::repo(repo_path)?;
+	let repo = repo(repo_path)?;
 	let cur_ref = repo.head()?;
 
 	if !repo
@@ -345,12 +346,12 @@ pub fn checkout_remote_branch(
 
 /// The user must not be on the branch for the branch to be deleted
 pub fn delete_branch(
-	repo_path: &str,
+	repo_path: &RepoPath,
 	branch_ref: &str,
 ) -> Result<()> {
 	scope_time!("delete_branch");
 
-	let repo = utils::repo(repo_path)?;
+	let repo = repo(repo_path)?;
 	let branch_as_ref = repo.find_reference(branch_ref)?;
 	let mut branch = git2::Branch::wrap(branch_as_ref);
 	if branch.is_head() {
@@ -361,10 +362,13 @@ pub fn delete_branch(
 }
 
 /// creates a new branch pointing to current HEAD commit and updating HEAD to new branch
-pub fn create_branch(repo_path: &str, name: &str) -> Result<String> {
+pub fn create_branch(
+	repo_path: &RepoPath,
+	name: &str,
+) -> Result<String> {
 	scope_time!("create_branch");
 
-	let repo = utils::repo(repo_path)?;
+	let repo = repo(repo_path)?;
 
 	let head_id = get_head_repo(&repo)?;
 	let head_commit = repo.find_commit(head_id.into())?;
@@ -386,7 +390,8 @@ mod tests_branch_name {
 	fn test_smoke() {
 		let (_td, repo) = repo_init().unwrap();
 		let root = repo.path().parent().unwrap();
-		let repo_path = root.as_os_str().to_str().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
 
 		assert_eq!(
 			get_branch_name(repo_path).unwrap().as_str(),
@@ -398,7 +403,8 @@ mod tests_branch_name {
 	fn test_empty_repo() {
 		let (_td, repo) = repo_init_empty().unwrap();
 		let root = repo.path().parent().unwrap();
-		let repo_path = root.as_os_str().to_str().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
 
 		assert!(matches!(
 			get_branch_name(repo_path),
@@ -416,7 +422,8 @@ mod tests_create_branch {
 	fn test_smoke() {
 		let (_td, repo) = repo_init().unwrap();
 		let root = repo.path().parent().unwrap();
-		let repo_path = root.as_os_str().to_str().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
 
 		create_branch(repo_path, "branch1").unwrap();
 
@@ -436,7 +443,8 @@ mod tests_branch_compare {
 	fn test_smoke() {
 		let (_td, repo) = repo_init().unwrap();
 		let root = repo.path().parent().unwrap();
-		let repo_path = root.as_os_str().to_str().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
 
 		create_branch(repo_path, "test").unwrap();
 
@@ -462,7 +470,8 @@ mod tests_branches {
 	fn test_smoke() {
 		let (_td, repo) = repo_init().unwrap();
 		let root = repo.path().parent().unwrap();
-		let repo_path = root.as_os_str().to_str().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
 
 		assert_eq!(
 			get_branches_info(repo_path, true)
@@ -478,7 +487,8 @@ mod tests_branches {
 	fn test_multiple() {
 		let (_td, repo) = repo_init().unwrap();
 		let root = repo.path().parent().unwrap();
-		let repo_path = root.as_os_str().to_str().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
 
 		create_branch(repo_path, "test").unwrap();
 
@@ -497,9 +507,18 @@ mod tests_branches {
 		let dir = dir.path().to_str().unwrap();
 
 		write_commit_file(&repo, "f1.txt", "foo", "c1");
-		rename_branch(dir, "refs/heads/master", branch_name).unwrap();
-		push(dir, "origin", branch_name, false, false, None, None)
+		rename_branch(&dir.into(), "refs/heads/master", branch_name)
 			.unwrap();
+		push(
+			&dir.into(),
+			"origin",
+			branch_name,
+			false,
+			false,
+			None,
+			None,
+		)
+		.unwrap();
 	}
 
 	#[test]
@@ -516,7 +535,8 @@ mod tests_branches {
 		clone_branch_commit_push(r2_path, "r2branch");
 
 		let root = repo.path().parent().unwrap();
-		let repo_path = root.as_os_str().to_str().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
 
 		//add the remotes
 		repo.remote("r1", r1_path).unwrap();
@@ -588,7 +608,8 @@ mod tests_branches {
 	fn test_branch_remote_no_upstream() {
 		let (_r, repo) = repo_init().unwrap();
 		let root = repo.path().parent().unwrap();
-		let repo_path = root.as_os_str().to_str().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
 
 		assert_eq!(
 			get_branch_remote(repo_path, "master").unwrap(),
@@ -600,7 +621,8 @@ mod tests_branches {
 	fn test_branch_remote_no_branch() {
 		let (_r, repo) = repo_init().unwrap();
 		let root = repo.path().parent().unwrap();
-		let repo_path = root.as_os_str().to_str().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
 
 		assert!(get_branch_remote(repo_path, "foo").is_err());
 	}
@@ -615,7 +637,8 @@ mod tests_checkout {
 	fn test_smoke() {
 		let (_td, repo) = repo_init().unwrap();
 		let root = repo.path().parent().unwrap();
-		let repo_path = root.as_os_str().to_str().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
 
 		assert!(
 			checkout_branch(repo_path, "refs/heads/master").is_ok()
@@ -629,7 +652,8 @@ mod tests_checkout {
 	fn test_multiple() {
 		let (_td, repo) = repo_init().unwrap();
 		let root = repo.path().parent().unwrap();
-		let repo_path = root.as_os_str().to_str().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
 
 		create_branch(repo_path, "test").unwrap();
 
@@ -650,7 +674,8 @@ mod test_delete_branch {
 	fn test_delete_branch() {
 		let (_td, repo) = repo_init().unwrap();
 		let root = repo.path().parent().unwrap();
-		let repo_path = root.as_os_str().to_str().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
 
 		create_branch(repo_path, "branch1").unwrap();
 		create_branch(repo_path, "branch2").unwrap();
@@ -720,16 +745,30 @@ mod test_remote_branches {
 		write_commit_file(&clone1, "test.txt", "test", "commit1");
 
 		push(
-			clone1_dir, "origin", "master", false, false, None, None,
+			&clone1_dir.into(),
+			"origin",
+			"master",
+			false,
+			false,
+			None,
+			None,
 		)
 		.unwrap();
 
-		create_branch(clone1_dir, "foo").unwrap();
+		create_branch(&clone1_dir.into(), "foo").unwrap();
 
 		write_commit_file(&clone1, "test.txt", "test2", "commit2");
 
-		push(clone1_dir, "origin", "foo", false, false, None, None)
-			.unwrap();
+		push(
+			&clone1_dir.into(),
+			"origin",
+			"foo",
+			false,
+			false,
+			None,
+			None,
+		)
+		.unwrap();
 
 		// clone2
 
@@ -739,11 +778,12 @@ mod test_remote_branches {
 		let clone2_dir = clone2_dir.path().to_str().unwrap();
 
 		let local_branches =
-			get_branches_info(clone2_dir, true).unwrap();
+			get_branches_info(&clone2_dir.into(), true).unwrap();
 
 		assert_eq!(local_branches.len(), 1);
 
-		let branches = get_branches_info(clone2_dir, false).unwrap();
+		let branches =
+			get_branches_info(&clone2_dir.into(), false).unwrap();
 		assert_eq!(dbg!(&branches).len(), 3);
 		assert_eq!(&branches[0].name, "origin/HEAD");
 		assert_eq!(&branches[1].name, "origin/foo");
@@ -762,13 +802,27 @@ mod test_remote_branches {
 
 		write_commit_file(&clone1, "test.txt", "test", "commit1");
 		push(
-			clone1_dir, "origin", "master", false, false, None, None,
+			&clone1_dir.into(),
+			"origin",
+			"master",
+			false,
+			false,
+			None,
+			None,
 		)
 		.unwrap();
-		create_branch(clone1_dir, "foo").unwrap();
+		create_branch(&clone1_dir.into(), "foo").unwrap();
 		write_commit_file(&clone1, "test.txt", "test2", "commit2");
-		push(clone1_dir, "origin", "foo", false, false, None, None)
-			.unwrap();
+		push(
+			&clone1_dir.into(),
+			"origin",
+			"foo",
+			false,
+			false,
+			None,
+			None,
+		)
+		.unwrap();
 
 		// clone2
 
@@ -778,21 +832,28 @@ mod test_remote_branches {
 		let clone2_dir = clone2_dir.path().to_str().unwrap();
 
 		let local_branches =
-			get_branches_info(clone2_dir, true).unwrap();
+			get_branches_info(&clone2_dir.into(), true).unwrap();
 
 		assert_eq!(local_branches.len(), 1);
 
-		let branches = get_branches_info(clone2_dir, false).unwrap();
+		let branches =
+			get_branches_info(&clone2_dir.into(), false).unwrap();
 
 		// checkout origin/foo
-		checkout_remote_branch(clone2_dir, &branches[1]).unwrap();
+		checkout_remote_branch(&clone2_dir.into(), &branches[1])
+			.unwrap();
 
 		assert_eq!(
-			get_branches_info(clone2_dir, true).unwrap().len(),
+			get_branches_info(&clone2_dir.into(), true)
+				.unwrap()
+				.len(),
 			2
 		);
 
-		assert_eq!(&get_branch_name(clone2_dir).unwrap(), "foo");
+		assert_eq!(
+			&get_branch_name(&clone2_dir.into()).unwrap(),
+			"foo"
+		);
 	}
 
 	#[test]
@@ -809,13 +870,19 @@ mod test_remote_branches {
 
 		write_commit_file(&clone1, "test.txt", "test", "commit1");
 		push(
-			clone1_dir, "origin", "master", false, false, None, None,
+			&clone1_dir.into(),
+			"origin",
+			"master",
+			false,
+			false,
+			None,
+			None,
 		)
 		.unwrap();
-		create_branch(clone1_dir, branch_name).unwrap();
+		create_branch(&clone1_dir.into(), branch_name).unwrap();
 		write_commit_file(&clone1, "test.txt", "test2", "commit2");
 		push(
-			clone1_dir,
+			&clone1_dir.into(),
 			"origin",
 			branch_name,
 			false,
@@ -831,12 +898,14 @@ mod test_remote_branches {
 			repo_clone(r1_dir.path().to_str().unwrap()).unwrap();
 		let clone2_dir = clone2_dir.path().to_str().unwrap();
 
-		let branches = get_branches_info(clone2_dir, false).unwrap();
+		let branches =
+			get_branches_info(&clone2_dir.into(), false).unwrap();
 
-		checkout_remote_branch(clone2_dir, &branches[1]).unwrap();
+		checkout_remote_branch(&clone2_dir.into(), &branches[1])
+			.unwrap();
 
 		assert_eq!(
-			&get_branch_name(clone2_dir).unwrap(),
+			&get_branch_name(&clone2_dir.into()).unwrap(),
 			branch_name
 		);
 	}
@@ -853,16 +922,30 @@ mod test_remote_branches {
 
 		write_commit_file(&clone1, "test.txt", "test", "commit1");
 		push(
-			clone1_dir, "origin", "master", false, false, None, None,
+			&clone1_dir.into(),
+			"origin",
+			"master",
+			false,
+			false,
+			None,
+			None,
 		)
 		.unwrap();
-		create_branch(clone1_dir, "foo").unwrap();
+		create_branch(&clone1_dir.into(), "foo").unwrap();
 		write_commit_file(&clone1, "test.txt", "test2", "commit2");
-		push(clone1_dir, "origin", "foo", false, false, None, None)
-			.unwrap();
+		push(
+			&clone1_dir.into(),
+			"origin",
+			"foo",
+			false,
+			false,
+			None,
+			None,
+		)
+		.unwrap();
 
 		let branches_1 =
-			get_branches_info(clone1_dir, false).unwrap();
+			get_branches_info(&clone1_dir.into(), false).unwrap();
 
 		assert!(branches_1[0].remote_details().unwrap().has_tracking);
 		assert!(branches_1[1].remote_details().unwrap().has_tracking);
@@ -875,7 +958,7 @@ mod test_remote_branches {
 		let clone2_dir = clone2_dir.path().to_str().unwrap();
 
 		let branches_2 =
-			get_branches_info(clone2_dir, false).unwrap();
+			get_branches_info(&clone2_dir.into(), false).unwrap();
 
 		assert!(
 			!branches_2[0].remote_details().unwrap().has_tracking
