@@ -1,17 +1,18 @@
 use super::{
 	diff::{get_diff_raw, HunkHeader},
-	utils::repo,
+	RepoPath,
 };
 use crate::{
 	error::{Error, Result},
 	hash,
+	sync::repository::repo,
 };
 use git2::{ApplyLocation, ApplyOptions, Diff};
 use scopetime::scope_time;
 
 ///
 pub fn stage_hunk(
-	repo_path: &str,
+	repo_path: &RepoPath,
 	file_path: &str,
 	hunk_hash: u64,
 ) -> Result<()> {
@@ -36,7 +37,7 @@ pub fn stage_hunk(
 
 /// this will fail for an all untracked file
 pub fn reset_hunk(
-	repo_path: &str,
+	repo_path: &RepoPath,
 	file_path: &str,
 	hunk_hash: u64,
 ) -> Result<()> {
@@ -94,7 +95,7 @@ fn find_hunk_index(diff: &Diff, hunk_hash: u64) -> Option<usize> {
 
 ///
 pub fn unstage_hunk(
-	repo_path: &str,
+	repo_path: &RepoPath,
 	file_path: &str,
 	hunk_hash: u64,
 ) -> Result<bool> {
@@ -162,15 +163,16 @@ mod tests {
 		let file_path = Path::new("foo/foo.txt");
 		let (_td, repo) = repo_init_empty()?;
 		let root = repo.path().parent().unwrap();
-		let repo_path = root.as_os_str().to_str().unwrap();
-
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
 		let sub_path = root.join("foo/");
 
 		fs::create_dir_all(&sub_path)?;
 		File::create(&root.join(file_path))?.write_all(b"test")?;
 
+		let sub_path: &RepoPath = &sub_path.to_str().unwrap().into();
 		let diff = get_diff(
-			sub_path.to_str().unwrap(),
+			sub_path,
 			file_path.to_str().unwrap(),
 			false,
 			None,
