@@ -1,4 +1,5 @@
-use crate::{error::Result, sync::utils};
+use super::RepoPath;
+use crate::{error::Result, sync::repository::repo};
 use git2::RepositoryState;
 use scopetime::scope_time;
 
@@ -21,16 +22,19 @@ impl From<RepositoryState> for RepoState {
 			RepositoryState::Clean => Self::Clean,
 			RepositoryState::Merge => Self::Merge,
 			RepositoryState::RebaseMerge => Self::Rebase,
-			_ => Self::Other,
+			_ => {
+				log::warn!("state not supported yet: {:?}", state);
+				Self::Other
+			}
 		}
 	}
 }
 
 ///
-pub fn repo_state(repo_path: &str) -> Result<RepoState> {
+pub fn repo_state(repo_path: &RepoPath) -> Result<RepoState> {
 	scope_time!("repo_state");
 
-	let repo = utils::repo(repo_path)?;
+	let repo = repo(repo_path)?;
 
 	let state = repo.state();
 
