@@ -6,11 +6,12 @@ use crate::{
 		BranchListComponent, CommandBlocking, CommandInfo,
 		CommitComponent, CompareCommitsComponent, Component,
 		ConfirmComponent, CreateBranchComponent, DrawableComponent,
-		ExternalEditorComponent, FileFindPopup, HelpComponent,
-		InspectCommitComponent, MsgComponent, OptionsPopupComponent,
-		PullComponent, PushComponent, PushTagsComponent,
-		RenameBranchComponent, RevisionFilesPopup, SharedOptions,
-		StashMsgComponent, TagCommitComponent, TagListComponent,
+		ExternalEditorComponent, FetchComponent, FileFindPopup,
+		HelpComponent, InspectCommitComponent, MsgComponent,
+		OptionsPopupComponent, PullComponent, PushComponent,
+		PushTagsComponent, RenameBranchComponent, RevisionFilesPopup,
+		SharedOptions, StashMsgComponent, TagCommitComponent,
+		TagListComponent,
 	},
 	input::{Input, InputEvent, InputState},
 	keys::{KeyConfig, SharedKeyConfig},
@@ -22,7 +23,10 @@ use crate::{
 	AsyncAppNotification, AsyncNotification,
 };
 use anyhow::{bail, Result};
-use asyncgit::{sync, AsyncGitNotification, CWD};
+use asyncgit::{
+	sync::{self, RepoPathRef},
+	AsyncGitNotification,
+};
 use crossbeam_channel::Sender;
 use crossterm::event::{Event, KeyEvent};
 use std::{
@@ -40,6 +44,7 @@ use tui::{
 
 /// the main app type
 pub struct App {
+	repo: RepoPathRef,
 	do_quit: bool,
 	help: HelpComponent,
 	msg: MsgComponent,
@@ -55,6 +60,7 @@ pub struct App {
 	push_popup: PushComponent,
 	push_tags_popup: PushTagsComponent,
 	pull_popup: PullComponent,
+	fetch_popup: FetchComponent,
 	tag_commit_popup: TagCommitComponent,
 	create_branch_popup: CreateBranchComponent,
 	rename_branch_popup: RenameBranchComponent,
@@ -83,6 +89,7 @@ impl App {
 	///
 	#[allow(clippy::too_many_lines)]
 	pub fn new(
+		repo: RepoPathRef,
 		sender: &Sender<AsyncGitNotification>,
 		sender_app: &Sender<AsyncAppNotification>,
 		input: Input,
@@ -102,11 +109,13 @@ impl App {
 				key_config.clone(),
 			),
 			commit: CommitComponent::new(
+				repo.clone(),
 				queue.clone(),
 				theme.clone(),
 				key_config.clone(),
 			),
 			blame_file_popup: BlameFileComponent::new(
+				&repo,
 				&queue,
 				sender,
 				&strings::blame_title(&key_config),
@@ -114,23 +123,27 @@ impl App {
 				key_config.clone(),
 			),
 			revision_files_popup: RevisionFilesPopup::new(
+				repo.clone(),
 				&queue,
 				sender_app,
 				theme.clone(),
 				key_config.clone(),
 			),
 			stashmsg_popup: StashMsgComponent::new(
+				repo.clone(),
 				queue.clone(),
 				theme.clone(),
 				key_config.clone(),
 			),
 			inspect_commit_popup: InspectCommitComponent::new(
+				&repo,
 				&queue,
 				sender,
 				theme.clone(),
 				key_config.clone(),
 			),
 			compare_commits_popup: CompareCommitsComponent::new(
+				&repo,
 				&queue,
 				sender,
 				theme.clone(),
@@ -141,44 +154,59 @@ impl App {
 				key_config.clone(),
 			),
 			push_popup: PushComponent::new(
+				&repo,
 				&queue,
 				sender,
 				theme.clone(),
 				key_config.clone(),
 			),
 			push_tags_popup: PushTagsComponent::new(
+				&repo,
 				&queue,
 				sender,
 				theme.clone(),
 				key_config.clone(),
 			),
 			pull_popup: PullComponent::new(
+				&repo,
+				&queue,
+				sender,
+				theme.clone(),
+				key_config.clone(),
+			),
+			fetch_popup: FetchComponent::new(
+				repo.clone(),
 				&queue,
 				sender,
 				theme.clone(),
 				key_config.clone(),
 			),
 			tag_commit_popup: TagCommitComponent::new(
+				repo.clone(),
 				queue.clone(),
 				theme.clone(),
 				key_config.clone(),
 			),
 			create_branch_popup: CreateBranchComponent::new(
+				repo.clone(),
 				queue.clone(),
 				theme.clone(),
 				key_config.clone(),
 			),
 			rename_branch_popup: RenameBranchComponent::new(
+				repo.clone(),
 				queue.clone(),
 				theme.clone(),
 				key_config.clone(),
 			),
 			select_branch_popup: BranchListComponent::new(
+				repo.clone(),
 				queue.clone(),
 				theme.clone(),
 				key_config.clone(),
 			),
 			tags_popup: TagListComponent::new(
+				repo.clone(),
 				&queue,
 				sender,
 				theme.clone(),
@@ -207,12 +235,14 @@ impl App {
 			msg: MsgComponent::new(theme.clone(), key_config.clone()),
 			tab: 0,
 			revlog: Revlog::new(
+				&repo,
 				&queue,
 				sender,
 				theme.clone(),
 				key_config.clone(),
 			),
 			status_tab: Status::new(
+				repo.clone(),
 				&queue,
 				sender,
 				theme.clone(),
@@ -220,17 +250,20 @@ impl App {
 				options,
 			),
 			stashing_tab: Stashing::new(
+				&repo,
 				sender,
 				&queue,
 				theme.clone(),
 				key_config.clone(),
 			),
 			stashlist_tab: StashList::new(
+				repo.clone(),
 				&queue,
 				theme.clone(),
 				key_config.clone(),
 			),
 			files_tab: FilesTab::new(
+				repo.clone(),
 				sender_app,
 				&queue,
 				theme.clone(),
@@ -241,6 +274,7 @@ impl App {
 			key_config,
 			requires_redraw: Cell::new(false),
 			file_to_open: None,
+			repo,
 		}
 	}
 
@@ -297,24 +331,27 @@ impl App {
 			{
 				flags.insert(NeedsUpdate::COMMANDS);
 			} else if let Event::Key(k) = ev {
-				let new_flags = if k == self.key_config.tab_toggle {
+				let new_flags = if k
+					== self.key_config.keys.tab_toggle
+				{
 					self.toggle_tabs(false)?;
 					NeedsUpdate::COMMANDS
-				} else if k == self.key_config.tab_toggle_reverse {
+				} else if k == self.key_config.keys.tab_toggle_reverse
+				{
 					self.toggle_tabs(true)?;
 					NeedsUpdate::COMMANDS
-				} else if k == self.key_config.tab_status
-					|| k == self.key_config.tab_log
-					|| k == self.key_config.tab_files
-					|| k == self.key_config.tab_stashing
-					|| k == self.key_config.tab_stashes
+				} else if k == self.key_config.keys.tab_status
+					|| k == self.key_config.keys.tab_log
+					|| k == self.key_config.keys.tab_files
+					|| k == self.key_config.keys.tab_stashing
+					|| k == self.key_config.keys.tab_stashes
 				{
 					self.switch_tab(k)?;
 					NeedsUpdate::COMMANDS
-				} else if k == self.key_config.cmd_bar_toggle {
+				} else if k == self.key_config.keys.cmd_bar_toggle {
 					self.cmdbar.borrow_mut().toggle_more();
 					NeedsUpdate::empty()
-				} else if k == self.key_config.open_options {
+				} else if k == self.key_config.keys.open_options {
 					self.options_popup.show()?;
 					NeedsUpdate::ALL
 				} else {
@@ -331,6 +368,7 @@ impl App {
 				let result = match self.file_to_open.take() {
 					Some(path) => {
 						ExternalEditorComponent::open_file_in_editor(
+							&self.repo.borrow(),
 							Path::new(&path),
 						)
 					}
@@ -386,6 +424,7 @@ impl App {
 			self.push_popup.update_git(ev)?;
 			self.push_tags_popup.update_git(ev)?;
 			self.pull_popup.update_git(ev);
+			self.fetch_popup.update_git(ev);
 			self.select_branch_popup.update_git(ev)?;
 		}
 
@@ -418,6 +457,7 @@ impl App {
 			|| self.push_popup.any_work_pending()
 			|| self.push_tags_popup.any_work_pending()
 			|| self.pull_popup.any_work_pending()
+			|| self.fetch_popup.any_work_pending()
 			|| self.revision_files_popup.any_work_pending()
 			|| self.tags_popup.any_work_pending()
 	}
@@ -450,6 +490,7 @@ impl App {
 			push_popup,
 			push_tags_popup,
 			pull_popup,
+			fetch_popup,
 			tag_commit_popup,
 			create_branch_popup,
 			rename_branch_popup,
@@ -486,6 +527,7 @@ impl App {
 			push_popup,
 			push_tags_popup,
 			pull_popup,
+			fetch_popup,
 			options_popup,
 			reset,
 			msg
@@ -497,7 +539,7 @@ impl App {
 			return false;
 		}
 		if let Event::Key(e) = ev {
-			if e == self.key_config.quit {
+			if e == self.key_config.keys.quit {
 				self.do_quit = true;
 				return true;
 			}
@@ -507,7 +549,7 @@ impl App {
 
 	fn check_hard_exit(&mut self, ev: Event) -> bool {
 		if let Event::Key(e) = ev {
-			if e == self.key_config.exit {
+			if e == self.key_config.keys.exit {
 				self.do_quit = true;
 				return true;
 			}
@@ -537,15 +579,15 @@ impl App {
 	}
 
 	fn switch_tab(&mut self, k: KeyEvent) -> Result<()> {
-		if k == self.key_config.tab_status {
+		if k == self.key_config.keys.tab_status {
 			self.set_tab(0)?;
-		} else if k == self.key_config.tab_log {
+		} else if k == self.key_config.keys.tab_log {
 			self.set_tab(1)?;
-		} else if k == self.key_config.tab_files {
+		} else if k == self.key_config.keys.tab_files {
 			self.set_tab(2)?;
-		} else if k == self.key_config.tab_stashing {
+		} else if k == self.key_config.keys.tab_stashing {
 			self.set_tab(3)?;
-		} else if k == self.key_config.tab_stashes {
+		} else if k == self.key_config.keys.tab_stashes {
 			self.set_tab(4)?;
 		}
 
@@ -693,6 +735,14 @@ impl App {
 				}
 				flags.insert(NeedsUpdate::ALL);
 			}
+			InternalEvent::FetchRemotes => {
+				if let Err(error) = self.fetch_popup.fetch() {
+					self.queue.push(InternalEvent::ShowErrorMsg(
+						error.to_string(),
+					));
+				}
+				flags.insert(NeedsUpdate::ALL);
+			}
 			InternalEvent::PushTags => {
 				self.push_tags_popup.push_tags()?;
 				flags.insert(NeedsUpdate::ALL);
@@ -752,7 +802,10 @@ impl App {
 				}
 			}
 			Action::StashDrop(_) | Action::StashPop(_) => {
-				if let Err(e) = StashList::action_confirmed(&action) {
+				if let Err(e) = StashList::action_confirmed(
+					&self.repo.borrow(),
+					&action,
+				) {
 					self.queue.push(InternalEvent::ShowErrorMsg(
 						e.to_string(),
 					));
@@ -761,16 +814,22 @@ impl App {
 				flags.insert(NeedsUpdate::ALL);
 			}
 			Action::ResetHunk(path, hash) => {
-				sync::reset_hunk(CWD, &path, hash)?;
+				sync::reset_hunk(&self.repo.borrow(), &path, hash)?;
 				flags.insert(NeedsUpdate::ALL);
 			}
 			Action::ResetLines(path, lines) => {
-				sync::discard_lines(CWD, &path, &lines)?;
+				sync::discard_lines(
+					&self.repo.borrow(),
+					&path,
+					&lines,
+				)?;
 				flags.insert(NeedsUpdate::ALL);
 			}
-			Action::DeleteBranch(branch_ref, true) => {
-				if let Err(e) = sync::delete_branch(CWD, &branch_ref)
-				{
+			Action::DeleteLocalBranch(branch_ref) => {
+				if let Err(e) = sync::delete_branch(
+					&self.repo.borrow(),
+					&branch_ref,
+				) {
 					self.queue.push(InternalEvent::ShowErrorMsg(
 						e.to_string(),
 					));
@@ -778,8 +837,9 @@ impl App {
 				flags.insert(NeedsUpdate::ALL);
 				self.select_branch_popup.update_branches()?;
 			}
-			Action::DeleteBranch(branch_ref, false) => {
+			Action::DeleteRemoteBranch(branch_ref) => {
 				self.queue.push(
+					//TODO: check if this is correct based on the fix in `c6abbaf`
 					branch_ref.rsplit('/').next().map_or_else(
 						|| {
 							InternalEvent::ShowErrorMsg(format!(
@@ -800,7 +860,9 @@ impl App {
 				self.select_branch_popup.update_branches()?;
 			}
 			Action::DeleteTag(tag_name) => {
-				if let Err(error) = sync::delete_tag(CWD, &tag_name) {
+				if let Err(error) =
+					sync::delete_tag(&self.repo.borrow(), &tag_name)
+				{
 					self.queue.push(InternalEvent::ShowErrorMsg(
 						error.to_string(),
 					));
