@@ -118,21 +118,25 @@ pub fn common_nav(
 	key: crossterm::event::KeyEvent,
 	key_config: &SharedKeyConfig,
 ) -> Option<MoveSelection> {
-	if key == key_config.move_down {
+	if key == key_config.keys.move_down {
 		Some(MoveSelection::Down)
-	} else if key == key_config.move_up {
+	} else if key == key_config.keys.move_up {
 		Some(MoveSelection::Up)
-	} else if key == key_config.page_up {
+	} else if key == key_config.keys.page_up {
 		Some(MoveSelection::PageUp)
-	} else if key == key_config.page_down {
+	} else if key == key_config.keys.page_down {
 		Some(MoveSelection::PageDown)
-	} else if key == key_config.move_right {
+	} else if key == key_config.keys.move_right {
 		Some(MoveSelection::Right)
-	} else if key == key_config.move_left {
+	} else if key == key_config.keys.move_left {
 		Some(MoveSelection::Left)
-	} else if key == key_config.home || key == key_config.shift_up {
+	} else if key == key_config.keys.home
+		|| key == key_config.keys.shift_up
+	{
 		Some(MoveSelection::Top)
-	} else if key == key_config.end || key == key_config.shift_down {
+	} else if key == key_config.keys.end
+		|| key == key_config.keys.shift_down
+	{
 		Some(MoveSelection::End)
 	} else {
 		None
